unit addlang;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  langsup, StdCtrls, Buttons;

type
  TAddLanguageState = (alNavigating,alEdited);
  TFormAddLanguage = class(TForm)
    GroupBox1: TGroupBox;
    ComboBoxSource: TComboBox;
    ComboBoxDestination: TComboBox;
    Label1: TLabel;
    Label2: TLabel;
    ButtonClose: TButton;
    GroupBox2: TGroupBox;
    BitBtnFirst: TBitBtn;
    BitBtnPrev: TBitBtn;
    BitBtnNext: TBitBtn;
    BitBtnLast: TBitBtn;
    EditQuellwort: TEdit;
    EditZielwort: TEdit;
    ButtonFontQuelle: TButton;
    ButtonFontZiel: TButton;
    FontDialog: TFontDialog;
    Label3: TLabel;
    EditContext: TEdit;
    BitBtnStore: TBitBtn;
    BitBtnCancel: TBitBtn;
    procedure FormCreate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure ButtonCloseClick(Sender: TObject);
    procedure ButtonFontQuelleClick(Sender: TObject);
    procedure ButtonFontZielClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure BitBtnFirstClick(Sender: TObject);
    procedure BitBtnLastClick(Sender: TObject);
    procedure BitBtnNextClick(Sender: TObject);
    procedure BitBtnPrevClick(Sender: TObject);
    procedure ComboBoxDestinationChange(Sender: TObject);
    procedure ComboBoxSourceChange(Sender: TObject);
    procedure EditZielwortChange(Sender: TObject);
    procedure BitBtnStoreClick(Sender: TObject);
    procedure BitBtnCancelClick(Sender: TObject);
  private
    firstActivate: boolean;
    slContextAndText: TStringList;
    Current         : integer;
    FState          : TAddLanguageState;
    text            : string;
    oldContext      : string;
    procedure hasChanged;
    procedure setState(state: TAddLanguageState);
  public
    language: TLangSup;
  end;


implementation

{$R *.DFM}

procedure TFormAddLanguage.FormCreate(Sender: TObject);
begin
  firstActivate    := true;
  slContextAndText := TStringList.Create;
  Current          := 0;
  text             := '';
  setState(alNavigating);
end;

procedure TFormAddLanguage.FormActivate(Sender: TObject);
var sl: TStringList;
begin
  if (firstActivate) then
     begin
       sl := TStringList.Create;
       try
          language.GetLanguages(sl);
          ComboboxSource.Items.Assign(sl);
          sl.Clear;
          language.GetLanguages(sl);
          ComboboxDestination.Items.Assign(sl);
       finally
          sl.Free;
       end;
       language.GetContextAndText(slContextAndText);

       (*--- Fremdsprachen ---*)
       oldContext := language.GetContext;
       language.SetContext('AddLanguage');
       language.SetCaptions(self);

       Caption := Caption + ' (' + language.GetFilename + ')';
     end;
  firstActivate := false;
end;

procedure TFormAddLanguage.ButtonCloseClick(Sender: TObject);
begin
  Close;
end;

procedure TFormAddLanguage.ButtonFontQuelleClick(Sender: TObject);
begin
  if (FontDialog.Execute) then
     begin
       ComboboxSource.Font := FontDialog.Font;
       EditQuellwort.Font  := FontDialog.Font;
     end;
end;

procedure TFormAddLanguage.ButtonFontZielClick(Sender: TObject);
begin
  if (FontDialog.Execute) then
     begin
       ComboboxDestination.Font := FontDialog.Font;
       EditZielwort.Font        := FontDialog.Font;
     end;
end;

procedure TFormAddLanguage.FormDestroy(Sender: TObject);
begin
  language.SetContext(oldContext);
  slContextAndText.Free;
end;

procedure TFormAddLanguage.BitBtnFirstClick(Sender: TObject);
begin
  Current := 0;
  hasChanged;
end;


procedure split(s: string; var language,context,text,translated: string);
var i,part: integer;
begin
  language   := '';
  context    := '';
  text       := '';
  translated := '';
  part := 0;
  for i := 1 to length(s) do
      if (s[i] = '|') then
         inc(part)
      else
      if (part = 0) then
         language := language + s[i]
      else
      if (part = 1) then
         context := context + s[i]
      else
      if (part = 2) then
         text := text + s[i]
      else
      if (part = 3) then
         translated := translated + s[i];
end;


procedure TFormAddLanguage.hasChanged;
var s,context: string;
    p: integer;
begin
  if ((Current >= 0) and (Current < slContextAndText.Count)) then
     begin
       s := slContextAndText.Strings[Current];
       p := pos('|',s);
       context := copy(s,1,p-1);
       text    := copy(s,p+1,length(s));
       EditContext.Text   := copy(s,1,p-1);
       EditQuellwort.Text := copy(s,p+1,length(s));

       language.SetLanguage(ComboboxSource.Text);
       language.SetContext(context);
       EditQuellwort.Text := language.Get(text);

       language.SetLanguage(ComboboxDestination.Text);
       language.SetReadOnly(true);
       EditZielwort.Text := language.Get(text);
       language.SetReadOnly(false);
       setState(alNavigating);
     end;
end;

procedure TFormAddLanguage.BitBtnLastClick(Sender: TObject);
begin
  Current := slContextAndText.Count - 1;
  hasChanged;
end;

procedure TFormAddLanguage.BitBtnNextClick(Sender: TObject);
begin
  Current := Current + 1;
  if (Current >= slContextAndText.Count) then
     Current := slContextAndText.Count - 1;
  hasChanged;
end;

procedure TFormAddLanguage.BitBtnPrevClick(Sender: TObject);
begin
  Current := Current - 1;
  if (Current < 0) then
     Current := 0;
  hasChanged;
end;

procedure TFormAddLanguage.ComboBoxDestinationChange(Sender: TObject);
begin
  hasChanged;
  setState(alNavigating);
end;

procedure TFormAddLanguage.ComboBoxSourceChange(Sender: TObject);
begin
  hasChanged;
end;

procedure TFormAddLanguage.EditZielwortChange(Sender: TObject);
begin
  setState(alEdited);
end;

procedure TFormAddLanguage.BitBtnStoreClick(Sender: TObject);
var newText: string;
begin
  newText := EditZielwort.Text;
  hasChanged;
  language.delete(text);
  language.put(text,newText);
  hasChanged;
  setState(alNavigating);
end;

procedure TFormAddLanguage.BitBtnCancelClick(Sender: TObject);
begin
  hasChanged;
  setState(alNavigating);
end;


procedure TFormAddLanguage.setState(state: TAddLanguageState);
begin
  FState := state;
  case FState of
    alNavigating:
    begin
      BitBtnFirst.Enabled  := true;
      BitBtnPrev.Enabled   := true;
      BitBtnNext.Enabled   := true;
      BitBtnLast.Enabled   := true;

      BitBtnStore.Enabled  := false;
      BitBtnCancel.Enabled := false;
    end;
    alEdited:
    begin
      BitBtnFirst.Enabled  := false;
      BitBtnPrev.Enabled   := false;
      BitBtnNext.Enabled   := false;
      BitBtnLast.Enabled   := false;

      BitBtnStore.Enabled  := true;
      BitBtnCancel.Enabled := true;
    end;
  end;
end;

end.
